![My Home Assistant](https://img.shields.io/badge/Home%20Assistant-%2341BDF5.svg?style=flat&logo=home-assistant&label=My)

![PyPI - Version](https://img.shields.io/pypi/v/eq3btsmart?logo=python&logoColor=green&color=blue)
![GitHub License](https://img.shields.io/github/license/eulemitkeule/eq3btsmart)
![GitHub Sponsors](https://img.shields.io/github/sponsors/eulemitkeule?logo=GitHub-Sponsors)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=EuleMitKeule_eq3btsmart&metric=coverage)](https://sonarcloud.io/summary/new_code?id=EuleMitKeule_eq3btsmart)

[![Code Quality](https://github.com/EuleMitKeule/eq3btsmart/actions/workflows/quality.yml/badge.svg)](https://github.com/EuleMitKeule/eq3btsmart/actions/workflows/quality.yml)
[![Publish](https://github.com/EuleMitKeule/eq3btsmart/actions/workflows/publish.yml/badge.svg)](https://github.com/EuleMitKeule/eq3btsmart/actions/workflows/publish.yml)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=EuleMitKeule_eq3btsmart&metric=bugs)](https://sonarcloud.io/summary/new_code?id=EuleMitKeule_eq3btsmart)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=EuleMitKeule_eq3btsmart&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=EuleMitKeule_eq3btsmart)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=EuleMitKeule_eq3btsmart&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=EuleMitKeule_eq3btsmart)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=EuleMitKeule_eq3btsmart&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=EuleMitKeule_eq3btsmart)

# eQ-3 Bluetooth Smart Thermostats
A Python library for interaction with [eQ-3 Bluetooth Smart Thermostat](https://www.eq-3.de/produkte/eqiva/detail/bluetooth-smart-heizkoerperthermostat.html) devices using [bleak](https://github.com/hbldh/bleak) and `asyncio`.
